@@ -6,14 +6,15 @@ from reportlab.lib.units import inch
 import sys
 
 class PDFSheet:
-    def __init__ (self, pagesize=letter, rows=4, cols=3, font='Helvetica', font_size=20):
+    def __init__ (self, pagesize=letter, rows=4, cols=3, font='Helvetica', font_size=20, left_adj=0.2*inch):
         self.pagesize = pagesize
         self.rows = rows
         self.cols = cols
         self.font = font
         self.font_size = font_size
         self.p_width, self.p_height = self.pagesize
-        self.block_width, self.block_height, = self.p_width / self.cols, self.p_height / self.rows
+        self.block_width, self.block_height, = (self.p_width - 2 * left_adj) / self.cols, self.p_height / self.rows
+        self.left_adj = left_adj
 
     def set_data (self, data_list):
         """
@@ -29,7 +30,6 @@ class PDFSheet:
         """
         self.data_list = data_list
 
-
     def render (self):
         c = canvas.Canvas (sys.stdout, self.pagesize)
         c.setFont (self.font, self.font_size)
@@ -37,8 +37,13 @@ class PDFSheet:
         # print (self.block_width, self.block_height)
 
         for idx, block in enumerate(self.data_list):
-            cur_row = (idx / self.cols) % self.rows
-            cur_col = idx % self.cols
+            cur_col = (idx / self.rows) % self.cols
+            cur_row = idx % self.rows
+            if cur_col == 0:
+                ladj = self.left_adj
+            else:
+                ladj = 0
+
             # print "row: {}, col: {}".format (cur_row, cur_col)
             
             origin = (cur_col * self.block_width,
@@ -50,7 +55,7 @@ class PDFSheet:
                 # c.drawString(origin[0] + entry[0] * inch,
                 #              origin[1] + entry[1] * inch,
                 #              entry[3])
-                textobject.setTextOrigin(origin[0] + entry[0] * inch,
+                textobject.setTextOrigin(origin[0] + entry[0] * inch + ladj,
                                          origin[1] + entry[1] * inch)
                 # textobject.setFont(self.font, self.font_size)
                 for l in split_with_num (entry[3], entry[2]):  
